==> knetworkmanager8-trinity_3.5.13.2.orig.tar.xz: knetworkmanager8-trinity-3.5.13.2/knetworkmanager-0.8/src/knetworkmanager-cellular_device_tray.h <==
/***************************************************************************
 *
 * knetworkmanager.h - A NetworkManager frontend for KDE 
 *
 * Copyright (C) 2005, 2006 Novell, Inc.
 *
 * Author: Timo Hoenig     <thoenig@suse.de>, <thoenig@nouse.net>
 *         Will Stephenson <wstephenson@suse.de>, <wstephenson@kde.org>
 *         Helmut Schaa    <hschaa@suse.de>, <helmut.schaa@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#ifndef KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H
#define KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H

// KNM includes
#include "knetworkmanager.h"
#include "devicetraycomponent.h"

// predefs
class CellularDevice;
class CellularDeviceTrayPrivate;

class CellularDeviceTray : public DeviceTrayComponent
{
	Q_OBJECT
  TQ_OBJECT
	public:
		CellularDeviceTray (CellularDevice*, KSystemTray * parent = 0, const char * name = 0);
		~CellularDeviceTray ();

		void addMenuItems(KPopupMenu* menu);

	public slots:
		void newConnection();

	private:
		CellularDeviceTrayPrivate* d;
};

#endif /* KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H */

==> knetworkmanager8-trinity-14.0.6.tar.xz: knetworkmanager8-trinity-14.0.6/knetworkmanager-0.8/src/knetworkmanager-cellular_device_tray.h <==
/***************************************************************************
 *
 * knetworkmanager.h - A NetworkManager frontend for KDE 
 *
 * Copyright (C) 2005, 2006 Novell, Inc.
 *
 * Author: Timo Hoenig     <thoenig@suse.de>, <thoenig@nouse.net>
 *         Will Stephenson <wstephenson@suse.de>, <wstephenson@kde.org>
 *         Helmut Schaa    <hschaa@suse.de>, <helmut.schaa@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#ifndef KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H
#define KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H

// KNM includes
#include "knetworkmanager.h"
#include "devicetraycomponent.h"

// predefs
class CellularDevice;
class CellularDeviceTrayPrivate;

class CellularDeviceTray : public DeviceTrayComponent
{
	Q_OBJECT
  
	public:
		CellularDeviceTray (CellularDevice*, KSystemTray * parent = 0, const char * name = 0);
		~CellularDeviceTray ();

		void addMenuItems(TDEPopupMenu* menu);

	public slots:
		void newConnection();

	private:
		CellularDeviceTrayPrivate* d;
};

#endif /* KNETWORKMANAGER_CELLULAR_DEVICE_TRAY_H */
